"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileServiceContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
const file_service_client_1 = require("./file-service-client");
// 常规文件资源读取
let FileServiceContribution = class FileServiceContribution {
    constructor() {
        this._disposables = new ide_core_browser_1.DisposableStore();
        // 初始化资源读取逻辑，需要在最早初始化时注册
        // 否则后续注册的 debug\user_stroage 等将无法正常使用
        this._disposables.add(this.fileSystem.registerProvider(ide_core_browser_1.Schemes.file, this.diskFileServiceProvider));
    }
    async initialize() {
        const fsProviderContributions = this.contributionProvider.getContributions();
        await Promise.all(fsProviderContributions.map(async (contrib) => {
            contrib.registerProvider && (await contrib.registerProvider(this.fileSystem));
        }));
        await Promise.all(fsProviderContributions.map(async (contrib) => {
            contrib.onFileServiceReady && (await contrib.onFileServiceReady());
        }));
    }
    dispose() {
        this._disposables.dispose();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IFileServiceClient),
    tslib_1.__metadata("design:type", file_service_client_1.FileServiceClient)
], FileServiceContribution.prototype, "fileSystem", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IDiskFileProvider),
    tslib_1.__metadata("design:type", Object)
], FileServiceContribution.prototype, "diskFileServiceProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.FsProviderContribution),
    tslib_1.__metadata("design:type", Object)
], FileServiceContribution.prototype, "contributionProvider", void 0);
FileServiceContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(ide_core_browser_1.ClientAppContribution),
    tslib_1.__metadata("design:paramtypes", [])
], FileServiceContribution);
exports.FileServiceContribution = FileServiceContribution;
//# sourceMappingURL=file-service-contribution.js.map